pub fn import_outcome(submission: &MockSubmission) -> ResponseItemExpand description
Read back from the submission, the way Suotar answers after its send.
pub fn import_outcome(submission: &MockSubmission) -> ResponseItemRead back from the submission, the way Suotar answers after its send.