pub fn write_and_send(
working: &mut WorkingSet,
submission: MockSubmission,
) -> ResponseItemExpand description
Writes the submission and sends it: refused by Sisu when the world holds violations for it, accepted otherwise.
pub fn write_and_send(
working: &mut WorkingSet,
submission: MockSubmission,
) -> ResponseItemWrites the submission and sends it: refused by Sisu when the world holds violations for it, accepted otherwise.